pub fn max_exponents_size<L: SecurityLevel>() -> (u32, u32)Expand description
Determines max size of exponents
During the CGGMP24 protocol, we often calculate $s^x t^y \mod N$. Given the security level we can determine max size of $x$ and $y$ in bits.
Size of exponents can be used to build a multiexp table.
Returns (x_bits, y_bits)